import asyncio
from typing import Optional

import aiohttp

from .errors import *


class SMR:

    def __init__(self, loop: asyncio.AbstractEventLoop=None):
        if loop is None:
            loop = asyncio.get_event_loop()

        self._session = aiohttp.ClientSession(
            loop=loop
        )
        self.__url = "https://some-random-api.ml"


    async def get_point(self, category: str=None, name: str=None, path: str=None):
        """
        Examples:

        await smr_async.SMR().get_point(category="canvas", path="?avatar='avatar_url'..."
        """
        async with self._session.get(f'{self.__url}/{name}' if None in (category, path) else f'{self.__url}/{category}/{name}' if path == None else f'{self.__url}/{category}/{name}' + path) as res:
            if res.ok:
                try:
                    a = await res.json()
                except:
                    a = str(res.url)
            else:
                raise NotFoundError("Не было найдено данной категории/имя и прочего. Проверьте путь ещё раз или же правильность написания пути/ссылок.")
            return a


import requests
from typing import Literal

from .errors import *


class SMR_client:

    def __init__(self):
        self._session = requests
        self.__url = "https://some-random-api.ml"

    def get_point(self, category: str=None, name: str=None, path: str=None):
        request = self._session.get(f'{self.__url}/{name}' if None in (category, path) else f'{self.__url}/{category}/{name}' if path == None else f'{self.__url}/{category}/{name}' + path)
        if request.ok:
            try:
                data = request.json()
            except:
                data = str(request.url)
        else:
            raise NotFoundError("Не было найдено данной категории/имя и прочего. Проверьте путь ещё раз или же правильность написания пути/ссылок.")
        return data



import setuptools
import pathlib


HERE = pathlib.Path(__file__).parent

README = (HERE / "README.md").read_text(encoding="utf8")

setuptools.setup(
	name="some_random_python",
	version="1.0.13",
	author="MagMigo",
	description="Simple wrapper for some-random-api on python.",
	long_description=README,
	long_description_content_type="text/markdown",
	url="https://github.com/MagM1go/smr",
	packages=setuptools.find_packages(),
	classifiers=[
		"Programming Language :: Python :: 3.10",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.7',
)
